==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/request/PublisherRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Publisher;
import microsoft.dynamics.crm.entity.collection.request.AppmoduleCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.DuplicaterecordCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.PublisheraddressCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SolutionCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SyncerrorCollectionRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

@JsonIgnoreType
public class PublisherRequest extends EntityRequest<Publisher> {

    public PublisherRequest(ContextPath contextPath, Optional<Object> value) {
        super(Publisher.class, contextPath, SchemaInfo.INSTANCE, value);
    }

    public SystemuserRequest createdby() {
        return new SystemuserRequest(contextPath.addSegment("createdby"), Optional.empty());
    }

    public SystemuserRequest modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedby"), Optional.empty());
    }

    public DuplicaterecordCollectionRequest publisher_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("Publisher_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest publisher_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("Publisher_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public SyncerrorCollectionRequest publisher_SyncErrors() {
        return new SyncerrorCollectionRequest(
                        contextPath.addSegment("Publisher_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest publisher_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("Publisher_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public SystemuserRequest modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedonbehalfby"), Optional.empty());
    }

    public OrganizationRequest organizationid() {
        return new OrganizationRequest(contextPath.addSegment("organizationid"), Optional.empty());
    }

    public DuplicaterecordCollectionRequest publisher_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("Publisher_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest publisher_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("Publisher_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public SolutionCollectionRequest publisher_solution() {
        return new SolutionCollectionRequest(
                        contextPath.addSegment("publisher_solution"), Optional.empty());
    }

    public SolutionRequest publisher_solution(String solutionid) {
        return new SolutionRequest(contextPath.addSegment("publisher_solution").addKeys(new NameValue(solutionid.toString())), Optional.empty());
    }

    public AppmoduleCollectionRequest publisher_appmodule() {
        return new AppmoduleCollectionRequest(
                        contextPath.addSegment("publisher_appmodule"), Optional.empty());
    }

    public AppmoduleRequest publisher_appmodule(String appmoduleid) {
        return new AppmoduleRequest(contextPath.addSegment("publisher_appmodule").addKeys(new NameValue(appmoduleid.toString())), Optional.empty());
    }

    public PublisheraddressCollectionRequest publisher_PublisherAddress() {
        return new PublisheraddressCollectionRequest(
                        contextPath.addSegment("Publisher_PublisherAddress"), Optional.empty());
    }

    public PublisheraddressRequest publisher_PublisherAddress(String publisheraddressid) {
        return new PublisheraddressRequest(contextPath.addSegment("Publisher_PublisherAddress").addKeys(new NameValue(publisheraddressid.toString())), Optional.empty());
    }

    public SystemuserRequest createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("createdonbehalfby"), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.45-sources.jar: microsoft/dynamics/crm/entity/request/PublisherRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Publisher;
import microsoft.dynamics.crm.entity.collection.request.AppmoduleCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.DuplicaterecordCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.PublisheraddressCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SolutionCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SyncerrorCollectionRequest;

@JsonIgnoreType
public class PublisherRequest extends EntityRequest<Publisher> {

    public PublisherRequest(ContextPath contextPath, Optional<Object> value) {
        super(Publisher.class, contextPath, value);
    }

    public SystemuserRequest createdby() {
        return new SystemuserRequest(contextPath.addSegment("createdby"), Optional.empty());
    }

    public SystemuserRequest modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedby"), Optional.empty());
    }

    public DuplicaterecordCollectionRequest publisher_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("Publisher_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest publisher_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("Publisher_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public SyncerrorCollectionRequest publisher_SyncErrors() {
        return new SyncerrorCollectionRequest(
                        contextPath.addSegment("Publisher_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest publisher_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("Publisher_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public SystemuserRequest modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedonbehalfby"), Optional.empty());
    }

    public OrganizationRequest organizationid() {
        return new OrganizationRequest(contextPath.addSegment("organizationid"), Optional.empty());
    }

    public DuplicaterecordCollectionRequest publisher_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("Publisher_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest publisher_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("Publisher_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public SolutionCollectionRequest publisher_solution() {
        return new SolutionCollectionRequest(
                        contextPath.addSegment("publisher_solution"), Optional.empty());
    }

    public SolutionRequest publisher_solution(String solutionid) {
        return new SolutionRequest(contextPath.addSegment("publisher_solution").addKeys(new NameValue(solutionid.toString())), Optional.empty());
    }

    public AppmoduleCollectionRequest publisher_appmodule() {
        return new AppmoduleCollectionRequest(
                        contextPath.addSegment("publisher_appmodule"), Optional.empty());
    }

    public AppmoduleRequest publisher_appmodule(String appmoduleid) {
        return new AppmoduleRequest(contextPath.addSegment("publisher_appmodule").addKeys(new NameValue(appmoduleid.toString())), Optional.empty());
    }

    public PublisheraddressCollectionRequest publisher_PublisherAddress() {
        return new PublisheraddressCollectionRequest(
                        contextPath.addSegment("Publisher_PublisherAddress"), Optional.empty());
    }

    public PublisheraddressRequest publisher_PublisherAddress(String publisheraddressid) {
        return new PublisheraddressRequest(contextPath.addSegment("Publisher_PublisherAddress").addKeys(new NameValue(publisheraddressid.toString())), Optional.empty());
    }

    public SystemuserRequest createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("createdonbehalfby"), Optional.empty());
    }

}
